@@ -78,9 +78,9 @@ module Aws::S3
 
     # This header can be used as a data integrity check to verify that the
     # data received is the same data that was originally sent. This header
-    # specifies the base64-encoded, 32-bit CRC32 checksum of the object. For
-    # more information, see [Checking object integrity][1] in the *Amazon S3
-    # User Guide*.
+    # specifies the base64-encoded, 32-bit CRC-32 checksum of the object.
+    # For more information, see [Checking object integrity][1] in the
+    # *Amazon S3 User Guide*.
     #
     #
     #
@@ -90,7 +90,7 @@ module Aws::S3
       data[:checksum_crc32]
     end
 
-    # The base64-encoded, 32-bit CRC32C checksum of the object. This will
+    # The base64-encoded, 32-bit CRC-32C checksum of the object. This will
     # only be present if it was uploaded with the object. When you use an
     # API operation on an object that was uploaded using multipart uploads,
     # this value may not be a direct checksum value of the full object.
@@ -262,7 +262,7 @@ module Aws::S3
           :retry
         end
       end
-      Aws::Plugins::UserAgent.feature('resource') do
+      Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         Aws::Waiters::Waiter.new(options).wait({})
       end
     end
@@ -500,7 +500,7 @@ module Aws::S3
         upload_id: @multipart_upload_id,
         part_number: @part_number
       )
-      resp = Aws::Plugins::UserAgent.feature('resource') do
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.upload_part_copy(options)
       end
       resp.data
@@ -558,9 +558,9 @@ module Aws::S3
     # @option options [String] :checksum_crc32
     #   This header can be used as a data integrity check to verify that the
     #   data received is the same data that was originally sent. This header
-    #   specifies the base64-encoded, 32-bit CRC32 checksum of the object. For
-    #   more information, see [Checking object integrity][1] in the *Amazon S3
-    #   User Guide*.
+    #   specifies the base64-encoded, 32-bit CRC-32 checksum of the object.
+    #   For more information, see [Checking object integrity][1] in the
+    #   *Amazon S3 User Guide*.
     #
     #
     #
@@ -568,7 +568,7 @@ module Aws::S3
     # @option options [String] :checksum_crc32c
     #   This header can be used as a data integrity check to verify that the
     #   data received is the same data that was originally sent. This header
-    #   specifies the base64-encoded, 32-bit CRC32C checksum of the object.
+    #   specifies the base64-encoded, 32-bit CRC-32C checksum of the object.
     #   For more information, see [Checking object integrity][1] in the
     #   *Amazon S3 User Guide*.
     #
@@ -650,7 +650,7 @@ module Aws::S3
         upload_id: @multipart_upload_id,
         part_number: @part_number
       )
-      resp = Aws::Plugins::UserAgent.feature('resource') do
+      resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
         @client.upload_part(options)
       end
       resp.data
